@@ -99,6 +99,7 @@ sub fill_package_cache ($self, $c) {
                         s/\(.*\)//;  # remove version details
                         s/\s//g;
                         s/,\s*$//;   # remove trailing comma
+                        s/:\w+//;    # remove arch qualifier
                         $_;
                     }
                     map { split /\s*[,|]\s*/ , $_->[0] } # extract dependency info from array ref
@@ -259,7 +260,9 @@ All C<control> files keyword are read in a case-insensitive manner.
 
 =head1 CONSTRUCTOR
 
-=head2 new ( node => $node_obj, name => 'Dpkg::Control' ) ;
+=head2 new
+
+Parameters: C<< node => $node_obj, name => 'Dpkg::Control' >>
 
 Inherited from L<Config::Model::Backend::Any>. The constructor will be
 called by L<Config::Model::AutoRead>.
