@@ -19,15 +19,15 @@ my $logger = get_logger("Backend::DpkgSyntax") ;
 sub parse_dpkg_file {
     my $self = shift ;
     my $file_path = shift;
-    my $fh = shift;
     my $check = shift || 'yes' ;
     my $comment_allowed = shift || 0 ;
 
-    my @lines = $fh->getlines ;
+    return  unless $file_path->is_file ;
+
+    my @lines = $file_path->lines_utf8 ;
     chomp @lines ;
-    $fh->close ;
-    
-    $self->parse_dpkg_lines ($file_path, \@lines, $check, $comment_allowed);
+
+    return $self->parse_dpkg_lines ($file_path, \@lines, $check, $comment_allowed);
 }
 
 #
@@ -132,7 +132,15 @@ sub parse_dpkg_lines {
             $logger->debug("Parse result section $i, found:") ;
             foreach my $key (keys %section_data) {
                 my $data = $section_data{$key};
-                $logger->debug( "$key: ". $data->[0][0]. (@$data > 1 ? ' ...':'')) ;
+                # first entry may be a comment
+                my $kd;
+                foreach my $it (@$data) {
+                    if (ref $it) {
+                        $kd =  $it->[0];
+                        last;
+                    }
+                }
+                $logger->debug( "$key: $kd" . (@$data > 1 ? ' ...':'')) ;
             }
         }
     }
@@ -165,14 +173,14 @@ sub _store_line_and_comments ($store_ref,$file_path,$line,$check,$line_nb, $hand
 
 # input is [ section [ keyword => value | value_list_ref ] ]
 sub write_dpkg_file {
-    my ($self, $ioh, $array_ref,$list_sep) = @_ ;
+    my ($self, $array_ref,$list_sep) = @_ ;
 
     my @lines = $self->format_dpkg_section(shift @$array_ref,$list_sep) ;
 
     foreach my $section (@$array_ref) {
         push @lines, '', $self->format_dpkg_section($section,$list_sep) ;
     }
-    $ioh->print ( join("\n", @lines ), "\n");
+    return join("\n", @lines ). "\n";
 }
 
 # TODO: also rework coyright and dpkgpatch to cope with new data structure
@@ -217,7 +225,7 @@ sub format_dpkg_list ($self, $name, $value_list_ref, $list_sep) {
             $comment_elt = '';
         }
         if ($idx == 0 and $comment_elt) {
-            $result .= $self->format_label_line($name, '');
+            $result .= $self->format_label_line($name, '')."\n";
             $result .= $comment_elt . "\n" . $pad . $list_elt  ;
         }
         elsif ($idx == 0) {
@@ -234,8 +242,8 @@ sub format_dpkg_list ($self, $name, $value_list_ref, $list_sep) {
 }
 
 sub write_dpkg_text {
-    my ($self, $ioh, $text) = @_ ;
-    $ioh->print ( join("\n", $self->format_dpkg_text('',$text)), "\n" );
+    my ($self, $text) = @_ ;
+    return  join("\n", $self->format_dpkg_text('',$text)). "\n" ;
 }
 
 sub format_dpkg_text {
@@ -480,7 +488,7 @@ structure like L<parse_dpkg_file>.
 
 =head2 write_dpkg_file
 
-Parameters C< ( io_handle, list_ref, list_sep ) >
+Parameters C< ( list_ref, list_sep ) >
 
 Munge the passed list ref into a string compatible with control files
 and write it in the passed file handle.
@@ -492,19 +500,19 @@ List items (like C<Depends> field in C<debian/control>) are joined
 with the value C<list_sep> before being written. Values are aligned in
 case of multi-line output of a list. Default value of C<list_sep> is "C<,\n>"
 
-For instance the following code :
+For instance, after the following code :
 
  my $ref = [ [ Foo => 'foo value' , Bar => [ 'v1', 'v2' ] ];
- write_dpkg_file ( $ioh, $ref, ', ' )
+ my $res = write_dpkg_file ( $ref, ', ' )
 
-yields:
+C<$res> contains:
 
  Foo: foo value
  Bar: v1, v2
 
 Here's an example using default C<$sep_list>:
 
- write_dpkg_file ( $ioh, $ref )
+ print write_dpkg_file ( $ref )
 
 yields:
 
