@@ -175,8 +175,8 @@ sub update ($self, %args) {
         @packed ;
 
     # load new data in config tree
-    foreach my $p (@packed) {
-        my ($id, @paths) = $p->@*;
+    foreach my $pack_data (@packed) {
+        my ($id, @paths) = $pack_data->@*;
 
         next if $id == 0; # skip entries without info
 
@@ -192,7 +192,7 @@ sub update ($self, %args) {
             my $old_data = delete $preserved_path{$p};
 
             my $using_old_data = 0;
-            if ($old_data) {
+            if ($old_data and $old_data->{Copyright} and $old_data->{License}{short_name}) {
                 if ($datum->{Copyright} =~ /unknown|no-info-found/i) {
                     $self->_say( "keeping copyright dir data for $p");
                     $datum->{Copyright} = $old_data->{Copyright};
@@ -258,7 +258,7 @@ sub update ($self, %args) {
         };
         if ($@) {
             die "Error: Data extracted from source file is corrupted:\n$@"
-                ."This usually mean that cme or licensecheck (or both)"
+                ."This usually mean that cme or licensecheck (or both) "
                 ."have a bug. You may work-around this issue by adding an override entry in "
                 ."fill.copyright.blanks file. See "
                 ."https://github.com/dod38fr/config-model/wiki/Updating-debian-copyright-file-with-cme "
@@ -518,10 +518,10 @@ Files entries are sorted and the new C<debian/copyright> is generated.
 
 =back
 
-=head1 update ( %args )
+=head1 update
 
 Updates data using the output
-L<Dpkg::Copyright::Scanner/"scan_files ( %args )">.
+L<Dpkg::Copyright::Scanner/scan_files">.
 
 Parameters in C<%args>:
 
