@@ -35,7 +35,7 @@ my $madison_endpoint = "https://$madison_host/madison";
 
 # list of virtual packages
 # See https://www.debian.org/doc/packaging-manuals/virtual-package-names-list.txt
-# updated from 08 Jan 2017 version
+# updated from 20 Feb 2019 version
 my @virtual_list = qw/
  adventure
  audio-mixer
@@ -71,14 +71,14 @@ my @virtual_list = qw/
  info-browser
  ispell-dictionary
  java5-runtime
- java6-runtime
- java7-runtime
- java8-runtime
- java9-runtime
  java5-runtime-headless
+ java6-runtime
  java6-runtime-headless
+ java7-runtime
  java7-runtime-headless
+ java8-runtime
  java8-runtime-headless
+ java9-runtime
  java9-runtime-headless
  kernel-headers
  kernel-image
@@ -138,6 +138,7 @@ my @virtual_list = qw/
 
 # other less official virtual packages
 push @virtual_list, qw/
+ debhelper-compat
  libgl-dev
  libqt5opengl5-desktop-dev
  libtiff-dev
@@ -187,6 +188,13 @@ my $grammar = << 'EOG' ;
         push @dep_errors, "$err: '$txt'" ;
         return ; # to ensure production error
     } ;
+    my $arch_list = qr/(any |alpha|amd64
+         |arm(64|eb|el|hf)?
+         |avr32 |hppa |i386 |ia64 |lpia |m32r |m68k
+         |mips(el|64el|64)?
+         |powerpc(el|spe)?
+         |ppc64\b |ppc64el |s390x?
+         |sh3\b |sh3eb |sh4\b |sh4eb |sparc\b |sparc64 |x32 )/x;
 }
 
 # comment this out when modifying the grammar
@@ -197,21 +205,19 @@ dependency: { @dep_errors = (); } <reject>
 dependency: depend(s /\|/) eofile {
     $return = [ 1 , @{$item[1]} ] ;
   }
+  # accept anything that contain a variable, see #911756 and #702792
+  | /.*\$\{[\w:\-]+\}.*/ { $return = [1, $item[1] ] ;}
   |  {
     push( @dep_errors, "Cannot parse: '$text'" ) unless @dep_errors ;
     $return =  [ 0, @dep_errors ];
   }
 
-depend: pkg_dep | variable
-
-# For the allowed stuff after ${foo}, see #702792
-variable: /\$\{[\w:\-]+\}[\w\.\-~+]*/
-
-pkg_dep: pkg_name dep_version(?) arch_restriction(?) profile_restriction(s?) {
+depend: pkg_name arch_qualifier(?) dep_version(?) arch_restriction(?) profile_restriction(s?) {
     my %ret = ( name => $item{pkg_name} );
-    $ret{dep}     = $item[2][0] if @{$item[2]};
-    $ret{arch}    = $item[3][0] if @{$item[3]};
-    $ret{profile} = $item[4] if @{$item[4]};
+    $ret{arch_qualifier}   = $item[2][0] if @{$item[2]};
+    $ret{dep}              = $item[3][0] if @{$item[3]};
+    $ret{arch_restriction} = $item[4][0] if @{$item[4]};
+    $ret{profile}          = $item[5]    if @{$item[5]};
     $return = \%ret ;
 }
 
@@ -235,6 +241,12 @@ profile_name: 'cross' | 'pkg' | 'stage1'| 'stage2' |
     $add_error->("Unknown build profile name '$bad'","Expected one of @a") ;
 }
 
+# see #911756
+arch_qualifier: ':' arch_qualifier_name  { $return = $item[2]; }
+
+arch_qualifier_name: 'native' | /$arch_list/x |
+   /\S+/ { $add_error->("bad architecture qualifier", $item[1]) ;}
+
 arch_restriction: '[' osarch(s) ']'
     {
         my $mismatch = 0;
@@ -253,17 +265,17 @@ arch_restriction: '[' osarch(s) ']'
 
 dep_version: '(' oper version ')' { $return = [ $item{oper}, $item{version} ] ;}
 
-pkg_name: /[a-z0-9][a-z0-9\+\-\.]+(?=[\s([|]|\Z)/
+pkg_name: /[a-z0-9][a-z0-9\+\-\.]+(?=[\s:([|]|\Z)/
     | /\S+/ { $add_error->("bad package name", $item[1]) ;}
 
 oper: '<<' | '<=' | '=' | '>=' | '>>'
     | /\S+/ { $add_error->("bad dependency version operator", $item[1]) ;}
 
-version: variable | /[\w\.\-~:+]+(?=\s|\)|\Z)/
+version: /[\w\.\-~:+]+(?=\s|\)|\Z)/
     | /\S+/ { $add_error->("bad dependency version", $item[1]) ;}
 
 # valid arch are listed by dpkg-architecture -L
-osarch: not(?) os(?) arch
+osarch: not(?) os(?) arch_restrict
     {
         $return =  [ $item[1][0], $item[2][0], $item[3] ];
     }
@@ -272,18 +284,12 @@ not: '!'
 
 os: /(any|uclibc-linux|linux|kfreebsd|knetbsd|kopensolaris|hurd|darwin|freebsd|netbsd|openbsd|solaris|uclinux)
    -/x
-   | /\w+/ '-' { $add_error->("bad os in architecture specification", $item[1]) ;}
+   | /\w+/ '-' { $add_error->("bad os in architecture restriction", $item[1]) ;}
 
-arch: / (any |alpha|amd64
-         |arm(64|eb|el|hf)?
-         |avr32 |hppa |i386 |ia64 |lpia |m32r |m68k
-         |mips(el|64el|64)?
-         |powerpc(el|spe)?
-         |ppc64\b |ppc64el |s390x?
-         |sh3\b |sh3eb |sh4\b |sh4eb |sparc\b |sparc64 |x32 )
-        (?=(\]| ))
+arch_restrict: / $arch_list
+        (?=(\]| |$))
       /x
-      | /\w+/ { $add_error->("bad arch in architecture specification", $item[1]) ;}
+      | /\w+/ { $add_error->("bad arch in architecture restriction", $item[1]) ;}
 
 
 eofile: /^\Z/
@@ -490,12 +496,6 @@ sub check_depend_chain {
     return $ret ;
 }
 
-sub extract_cpan_version {
-    my ($self,$v) = @_;
-    return undef unless defined $v ;
-    $v =~ /^(?:\d+:)?([\d\w.-]+?)(?:(?:\+\w+)?-[\w+~]+)?$/ ;
-    return $1;
-}
 
 # called through check_depend_chain
 # does modify $input when applying fix
@@ -506,158 +506,29 @@ sub check_perl_lib_dep {
 
     $logger->debug("called for $dep_name with $actual_dep with apply_fix $apply_fix");
 
-    my ($old_perl_dep) = grep { $_->{name} eq 'perl' } @$input;
-    my $old_perl_versioned_dep = $old_perl_dep->{dep}[1] // '';
+    my @perl_dep = grep { $_->{name} =~ /^perl(?:-modules)?$/ } @$input;
 
-    # The dependency should be in the form perl (>= 5.10.1) | libtest-simple-perl (>= 0.88)".
-    # cf http://pkg-perl.alioth.debian.org/policy.html#debian_control_handling
-    # If the Perl version is not available in sid, the order of the dependency should be reversed
-    # libcpan-meta-perl | perl (>= 5.13.10)
-    # because Debian build daemons use the first available alternative
+    # The dependency of module shipped with perl core used to be in the form:
+    # "perl (>= 5.10.1) | libtest-simple-perl (>= 0.88)".
+    # This is no longer needed and simple dependency (possibly versioned) on the library
+    # is enough.
+    # See this thread: https://lists.debian.org/debian-perl/2019/01/msg00000.html
 
-    # check for dual life module, module name follows debian convention...
-    my $cpan_name = $debian_map{$dep_name};
-    return 1 unless $cpan_name ;
+    # return if the dependency does not looks like an alternate perl module dependency
+    return 1 unless @perl_dep;
 
-    my $first_perl =  Module::CoreList->first_release($cpan_name) ;
-    return 1 unless $first_perl;
+    my @ideal_dep =  grep { $_->{name} !~ /^perl(?:-modules)?$/ } $input->@*;
 
-    my $deprecated = Module::CoreList->deprecated_in($cpan_name) ;
-    $logger->debug("dual life $dep_name is deprecated with perl $deprecated") if $deprecated;
-    my $removed    = Module::CoreList->removed_from($cpan_name) ;
-    $logger->debug("dual life $dep_name is removed from perl $removed") if $removed;
-
-    return 1 if (defined $dep_v && $dep_v =~ m/^\$/) ; # version like ${foobar} in lib dep
-
-    my %ideal_perl_dep ;
-    my %ideal_lib_dep ;
-
-    my @res = $self->get_available_version( $dep_name);
-
-    # check version for the first available version in Debian: debian
-    # dep may have no version specified but older versions can be found
-    # in CPAN that were never packaged in Debian
-
-	# get_available_version returns oldest first, like (etch,1.2,...)
-	my ($oldest_debian_with_lib,$oldest_lib_version_in_debian) = @res[0,1] ;
-	if (not defined $oldest_lib_version_in_debian or not defined $oldest_debian_with_lib) {
-		# no need to check further.
-		return 1;
-	}
-
-	# lob off debian release number
-	$oldest_lib_version_in_debian =~ s/-.*//;
-	my $check_v = $dep_v ;
-
-	# use oldest version only if the oldest version is NOT in oldstable
-	# second test can be removed end of April 2016 (cache expiry)
-    # but cached data for tests must be modified to respect the new convention
-	if (   $oldest_debian_with_lib !~ /oldstable/
-        or $oldest_debian_with_lib =~ /wheezy|jessie|stretch|buster|sid/
-    ) {
-		$check_v ||= $oldest_lib_version_in_debian ;
-		$logger->debug("dual life $dep_name has oldest debian $oldest_lib_version_in_debian, using $check_v");
-	}
-
-	my $cpan_dep_v = $self->extract_cpan_version($check_v);
-
-	my $v_decimal = Module::CoreList->first_release(
-		$cpan_name,
-		version->parse( $cpan_dep_v )
-	);
-
-    # return when module is not and was never part of core
-	return 1 unless defined $v_decimal;
-
-	my $v_normal = version->new($v_decimal)->normal;
-	$v_normal =~ s/^v//;    # loose the v prefix
-	if ( $logger->is_debug ) {
-		my $dep_str = $dep_name . ( defined $check_v ? ' ' . $check_v : '' );
-		$logger->debug("dual life $dep_str found in Perl core $v_normal (req perl is $old_perl_versioned_dep)");
-	}
-
-    if ( not defined $dep_v and $old_perl_versioned_dep and $old_perl_versioned_dep gt $v_decimal) {
-        # when alternate lib version is not defined (because the requirement is satisfied by all
-        # available versions of the lib), the actual requirement is held by the versioned dep of perl
-        # hence, it must be preserved
-        my $p_data = Module::CoreList->find_version($v_decimal);
-        $dep_v = $p_data->{$cpan_name};
-        $depend->{dep} = [ '>=', $dep_v ];
-        $logger->debug("preserving old perl versioned dep $old_perl_versioned_dep instead of $v_normal"
-                           ." for $dep_name (implies dep > $dep_v)");
-        $v_normal = $old_perl_versioned_dep;
-    }
-
-
-    my ($has_older_perl) = $self->check_versioned_dep( { name => 'perl', dep => ['>=', $v_normal]} );
-    my ($has_older_lib)  = $self->check_versioned_dep( $depend );
-
-    # Perl module is being or was removed from core
-    if ($deprecated or $removed) {
-        if ( $has_older_perl ) {
-            my $max_ver_normal = version->new($deprecated)->normal ;
-            $max_ver_normal =~ s/^v//;
-            $logger->debug("Found older perl for a soon to be removed lib. Using perl << $max_ver_normal dependency'");
-            $ideal_perl_dep{name} = 'perl';
-            $ideal_perl_dep{dep} = [ '<<', $max_ver_normal ];
-        }
-        else {
-            # e.g. perl (<< 5.8.0) i.e. lower than obsolete perl -> remove dependency from ideal perl dep
-            $logger->debug("Did not find older perl for an obsolete module. Perl dep should be removed");
-        }
-
-        # always specify the library dependency
-        $ideal_lib_dep{name} = $dep_name;
-        $ideal_lib_dep{dep} = [ '>=', $dep_v ] if $dep_v and $has_older_lib;
-
-    }
-    else {
-        # Perl module is part of core (this was tested before)
-        $ideal_perl_dep{name} = 'perl';
-        if ( $has_older_perl ) {
-            $logger->debug("Found older perl for a greater-than perl dep. Ideal perl dep is 'perl >= $v_normal'");
-            $ideal_perl_dep{dep} = [ '>=', $v_normal ];
-        }
-        else {
-            $logger->debug("Did no find older perl for a greater-than perl dep. Ideal perl dep is plain 'perl'");
-        }
-
-        # we need to specify the libray dependency even this one has no
-        # version requirement and the dependency is satisfied by Perl core
-        # because dual dependency will eventually be removed. Better keep this info
-        $ideal_lib_dep{name} = $dep_name;
-
-        if ($dep_v) {
-            $ideal_lib_dep{dep} = [ '>=', $dep_v ] if $dep_v and $has_older_lib;
-        }
-    }
-
-    my %perl_version =  $self->get_available_version( 'perl');
-    my $sid_perl_version = $perl_version{unstable} || $perl_version{sid} ;
-    my $has_older_perl_in_sid = ( $vs->compare( $v_normal, $sid_perl_version) < 0 ) ? 1 : 0;
-    $logger->debug(
-		"perl $v_normal is",
-		$has_older_perl_in_sid ? ' ' : ' not ',
-		"older than perl in sid ($sid_perl_version)"
-	);
-
-    my $perl_dep_first = $has_older_perl_in_sid && ! $deprecated;
-
-	my @pre_ordered_ideal_dep
-        = $perl_dep_first   ? ( \%ideal_perl_dep, \%ideal_lib_dep  )
-        :                     ( \%ideal_lib_dep,  \%ideal_perl_dep ) ;
-
-	my @ordered_ideal_dep = grep {defined $_->{name} } @pre_ordered_ideal_dep;
-
-	my $ideal_dep = $self->struct_to_dep( @ordered_ideal_dep );
+    # $depend contains only the libmodule part of the alternate dependency
+	my $ideal_dep = $self->struct_to_dep( @ideal_dep );
 
     die "Internal error: undefined ideal dep. Please report bug with the dependencies that triggered the bug"
         unless defined $ideal_dep;
 
 	if ( $actual_dep ne $ideal_dep ) {
-        my $msg = "Dependency of dual life package should be '$ideal_dep' not '$actual_dep'";
+        my $msg = "Dual dependency on perl module should be removed. I.e it should be '$ideal_dep' not '$actual_dep'";
 		if ($apply_fix) {
-			@$input =  @ordered_ideal_dep ; # notify_change called in check_value
+			@$input = @ideal_dep; # notify_change called in check_value
             if ($logger->is_info) {
                 $logger->info("fixed dependency with: '$ideal_dep', was '$actual_dep'");
             }
@@ -665,13 +536,6 @@ sub check_perl_lib_dep {
 		}
 		else {
 			$self->{nb_of_fixes}++;
-			my $msg = "Dependency of dual life package should be '$ideal_dep' not '$actual_dep'";
-            if ($deprecated) {
-                $msg .= " (deprecated from perl $deprecated)" ;
-            }
-            if ($removed) {
-                $msg .= " (removed from perl $removed)" ;
-            }
 			$self->add_warning ($msg);
 			$logger->info("will warn: $msg (fix++)");
 		}
@@ -884,6 +748,10 @@ my $cache_expire_date = time - 24 * 60 * 60 * 7 ;
 sub get_available_version {
     my ($self, $pkg_name) = @_ ;
 
+    # Store list of packages whose info could not be retrieved from madison
+    # to avoid repeating error messages
+    state %tried ;
+
     $logger->debug("called on $pkg_name");
 
     # don't query info for known virtual package
@@ -904,10 +772,17 @@ sub get_available_version {
         return @res;
     }
 
+    return () if $tried{$pkg_name};
+
+    if ($0 =~ /\.t$/ and not $ENV{CME_UPDATE_TEST_CACHE}) {
+        die "Cannot query madison during tests. Please ",
+            "run this test with CME_UPDATE_TEST_CACHE set to 1 to update the package cache\n";
+    }
+
     my $url = "$madison_endpoint?package=".uri_escape($pkg_name).'&f&b=deb' ;
     $self->instance->show_message("Connecting to $madison_host to check $pkg_name versions. Please wait...") ;
 	my $body = get($url);
-    my $res ;
+    my $res = [];
 	if (defined $body) {
         my $ref = extract_madison_info($body);
         $self->instance->show_message("got info for $pkg_name") ;
@@ -915,7 +790,8 @@ sub get_available_version {
         $logger->debug("pkg info is @$res");
     }
     else {
-        warn "cannot get data for package $pkg_name. Check your proxy ?\n" unless defined $body ;
+        warn "cannot get data for package $pkg_name from $madison_endpoint.\n" unless defined $body ;
+        $tried{$pkg_name} = 1;
     }
 
 	return $res->@*;
@@ -948,6 +824,11 @@ sub cache_info_from_madison {
         return;
     }
 
+    if ($0 =~ /\.t$/ and not $ENV{CME_UPDATE_TEST_CACHE}) {
+        die "Cannot query madison during tests. Please ",
+            "run this test with CME_UPDATE_TEST_CACHE set to 1 to update the package cache\n";
+    }
+
     my $url = "$madison_endpoint?package=".uri_escape(join(' ',@needed)).'&f&b=deb' ;
     $instance->show_message(
         "Connecting to $madison_host to check ", scalar @needed, " package versions. Please wait..."
@@ -1098,6 +979,11 @@ for about one month.
 
 =item *
 
+Dependencies containing variables (e.g. C<${foo}>) are accepted
+as-is. No check are performed.
+
+=item *
+
 Virtual package names are found scanning local apt cache. Hence an unknown package
 on your system may a virtual package on another system.
 
