@@ -71,8 +71,9 @@ If the maintainer\'s name contains a full stop then the whole field will not wor
         'class' => 'Config::Model::Dpkg::Control::Source::StandardVersion',
         'description' => 'This field indicates the Debian policy version number this package complies to.
 
-Before updating this field, please read L<upgrading-checklist|https://www.debian.org/doc/debian-policy/#document-upgrading-checklist>
+Before updating this field, please read L<upgrading-checklist|https://www.debian.org/doc/debian-policy/upgrading-checklist.html>
 to know what changes came with a new policy version number and apply the required changes (if any) to your package.',
+        'mandatory' => '1',
         'match' => '\\d+\\.\\d+\\.\\d+(\\.\\d+)?',
         'summary' => 'Debian policy version number this package complies to',
         'type' => 'leaf',
@@ -81,7 +82,7 @@ to know what changes came with a new policy version number and apply the require
           'current' => {
             'code' => '$_ eq $self->_fetch_std;',
             'fix' => '$_ = $self->_fetch_std; # restore default value',
-            'msg' => 'Current standards version is \'$std_value\'. Please read https://www.debian.org/doc/debian-policy/#document-upgrading-checklist for the changes that may be needed on your package to upgrade it from standard version \'$_\' to \'$std_value\'.
+            'msg' => 'Current standards version is \'$std_value\'. Please read https://www.debian.org/doc/debian-policy/upgrading-checklist.html for the changes that may be needed on your package to upgrade it from standard version \'$_\' to \'$std_value\'.
 '
           }
         }
@@ -590,6 +591,25 @@ The information is meant to be useful for a user knowledgeable in the given Vers
         'type' => 'leaf',
         'value_type' => 'uniline'
       },
+      'Rules-Requires-Root',
+      {
+        'description' => 'Depending on the value of the Rules-Requires-Root field, the package builder (e.g. dpkg-buildpackage) may run the debian/rules target as an unprivileged user and provide a gain root command. This command allows the debian/rules target to run particular subcommands under (fake)root. Can be \'no\', \'binary-targets\' (default)), or a space separated list of keywords containing a forward slash (e.g. "/").
+
+For details, see L<section 5.6.31.2 of Debian policy|https://www.debian.org/doc/debian-policy/ch-controlfields.html#rules-requires-root>',
+        'help' => {
+          '.+/' => 'Space separated list of keywords. These keywords must always contain a forward slash, which sets them apart from the other possible values of Rules-Requires-Root. When this list is provided, the builder must provide a gain root command (as defined in debian/rules and Rules-Requires-Root) or pretend that the value was set to binary-targets, and both the builder and the package’s debian/rules script must downgrade accordingly.',
+          'binary-targets' => '(Default) Declares that the package will need the root (or fakeroot) when either of the binary, binary-arch or binary-indep targets are called. This is how every tool behaved before this field was defined.',
+          'no' => 'Declares that neither root nor fakeroot is required. Package builders (e.g. dpkg-buildpackage) may choose to invoke any target in debian/rules with an unprivileged user.'
+        },
+        'summary' => 'Defines if access to root (or fakeroot) is required during build.',
+        'type' => 'leaf',
+        'value_type' => 'uniline',
+        'warn_unless_match' => {
+          '^no|binary-targets|([^\\P{PosixGraph}/]{2,}/\\p{PosixGraph}{2,}\\s*)+$' => {
+            'msg' => 'Invalid value. See help or Debian Policy chapter 5.6.31.2 for more information'
+          }
+        }
+      },
       'XS-Python-Version',
       {
         'status' => 'deprecated',
