@@ -2,7 +2,7 @@
   {
     'class_description' => 'describes how autopkgtest interprets and executes tests found in Debian source packages.
 
-See L<https://people.debian.org/~mpitt/autopkgtest/README.package-tests.html>',
+See L<https://salsa.debian.org/ci-team/autopkgtest/raw/master/doc/README.package-tests.rst>',
     'element' => [
       'Tests',
       {
@@ -32,7 +32,12 @@ Alternatively, a test command can be specified in C<Test-Command> parameter.',
           'isolation-container',
           'isolation-machine',
           'needs-reboot',
-          'needs-recommends'
+          'needs-recommends',
+          'flaky',
+          'skippable',
+          'skip-not-installable',
+          'hint-testsuite-triggers',
+          'superficial'
         ],
         'description' => 'Declares some restrictions or problems with the tests defined in this stanza. Depending on the test environment capabilities, user requests, and so on, restrictions can cause tests to be skipped or can cause the test to be run in a different manner.',
         'help' => {
@@ -45,12 +50,25 @@ When this restriction is present the test will usually be skipped unless the tes
 
 Please use this considerately, as for large builds it unnecessarily builds the entire project when you only need a tiny subset (like the tests/ subdirectory). It is often possible to run C<make -C tests> instead, or copy the test code to C<$AUTOPKGTEST_TMP> and build it there with some custom commands. This cuts down the load on the Continuous Integration servers and also makes tests more robust as it prevents accidentally running them against the built source tree instead of the installed packages.
 ',
+          'flaky' => 'The test is expected to fail intermittently, and is not suitable for gating continuous integration. This indicates a bug in either the package under test, a dependency or the test itself, but such bugs can be difficult to fix, and it is often difficult to know when the bug has been fixed without running the test for a while. If a flaky test succeeds, it will be treated like any other successful test, but if it fails it will be treated as though it had been skipped.',
+          'hint-testsuite-triggers' => 'This test exists purely as a hint to suggest when rerunning the tests is likely to be useful.  Specifically, it exists to influence the way dpkg-source generates the Testsuite-Triggers .dsc header from test metadata: the Depends for this test are to be added to Testsuite-Triggers.  (Just as they are for any other test.)
+
+The test with the hint-testsuite-triggers restriction should not actually be run.
+
+The packages listed as Depends for this test are usually indirect dependencies, updates to which are considered to pose a risk of regressions in other tests defined in this package.
+
+There is currently no way to specify this hint on a per-test basis; but in any case the debian.org machinery is not able to think about triggering individual tests.',
           'isolation-container' => 'The test wants to start services or open network TCP ports. This commonly fails in a simple chroot/schroot, so tests need to be run in their own container (e. g. autopkgtest-virt-lxc) or their own machine/VM (e. g. autopkgtest-virt-qemu or autopkgtest-virt-null). When running the test in a virtualization server which does not provide this (like autopkgtest-schroot) it will be skipped.',
           'isolation-machine' => 'The test wants to interact with the kernel, reboot the machine, or other things which fail in a simple schroot and even a container. Those tests need to be run in their own machine/VM (e. g. autopkgtest-virt-qemu or autopkgtest-virt-null). When running the test in a virtualization server which does not provide this it will be skipped.',
-          'needs-reboot' => 'The test wants to reboot the machine using /tmp/autopkgtest-reboot. See L<https://people.debian.org/~mpitt/autopkgtest/README.package-tests.html>',
+          'needs-reboot' => 'The test wants to reboot the machine using /tmp/autopkgtest-reboot. See L<https://salsa.debian.org/ci-team/autopkgtest/raw/master/doc/README.package-tests.rst>',
           'needs-recommends' => 'Enable installation of recommended packages in apt for the test dependencies. This does not affect build dependencies.',
           'needs-root' => 'The test script must be run as root.',
-          'rw-build-tree' => 'The test(s) needs write access to the built source tree (so it may need to be copied first). Even with this restriction, the test is not allowed to make any change to the built source tree which (i) isn\'t cleaned up by debian/rules clean, (ii) affects the future results of any test, or (iii) affects binary packages produced by the build tree in the future.'
+          'rw-build-tree' => 'The test(s) needs write access to the built source tree (so it may need to be copied first). Even with this restriction, the test is not allowed to make any change to the built source tree which (i) isn\'t cleaned up by debian/rules clean, (ii) affects the future results of any test, or (iii) affects binary packages produced by the build tree in the future.',
+          'skip-not-installable' => 'This test might have test dependencies that can\'t be fulfilled on all architectures. Therefore, when apt-get installs the dependencies, it will fail. Don\'t treat this as a test failure, but instead treat it as if the test was skipped.',
+          'skippable' => 'The test might need to be skipped for reasons that cannot be described by an existing restriction such as isolation-machine or breaks-testbed, but must instead be detected at runtime. If the test exits with status 77 (a convention borrowed from Automake), it will be treated as though it had been skipped. If it exits with any other status, its success or failure will be derived from the exit status and stderr as usual. Test authors must be careful to ensure that `kippable tests never exit with status 77 for reasons that should be treated as a failure.',
+          'superficial' => 'The test does not provide significant test coverage, so if it passes, that does not necessarily mean that the package under test is actually functional. If a superficial test fails, it will be treated like any other failing test, but if it succeeds, this is only a weak indication of success. Continuous integration systems should treat a package where all non-superficial tests are skipped as equivalent to a package where all tests are skipped.
+
+For example, a C library might have a superficial test that simply compiles, links and executes a "hello world" program against the library under test but does not attempt to make use of the library\'s functionality, while a Python or Perl library might have a superficial test that runs "import foo" or "require Foo;" but does not attempt to use the library beyond that.'
         },
         'type' => 'check_list'
       },
