@@ -29,12 +29,10 @@ our @tests = (
             'source Source',          "libdist-zilla-plugins-cjm-perl",
             'source Standards-Version' => $std_list[0],
             'source Build-Depends:0', "debhelper (>= 7)",
-            # not really happy about the versioned dep of libmeta-cpan-perl created ex-nihilo.
-            # this is a side effect of other compromises in dual dependency handling which should be harmless
-            'source Build-Depends-Indep:0', "libcpan-meta-perl (>= 2.110440) | perl (>= 5.13.10)",     # fixed
+            'source Build-Depends-Indep:0', "libcpan-meta-perl",     # fixed
             'source Build-Depends-Indep:1', "libdist-zilla-perl",    # fixed
             'source Build-Depends-Indep:5', "libpath-class-perl",
-            'source Build-Depends-Indep:6', "libmodule-build-perl (>= 0.360000) | perl (<< 5.19.0)", # fixed
+            'source Build-Depends-Indep:6', "libmodule-build-perl (>= 0.360000)", # fixed
             'source Build-Depends-Indep:7', "udev [linux-any] | makedev [linux-any]",
             'source X-Comment' => qr/Debian #810023/,
             'source Priority' => 'optional',
@@ -47,10 +45,9 @@ our @tests = (
         },
         log4perl_load_warnings => [ [ User => map { (warn => $_ ) } (
             qr/standards version/,
-            qr/dependency/, qr/dual life/, (qr/dependency/) x 2,
-            qr/libmodule-build-perl \(>= 0.360000\) \| perl \(>= 5.8.8\)/,
-            qr/should be 'libmodule-build-perl \(>= 0.360000\)/,
-            qr/dependency/, qr/dual life/, (qr/dependency/) x 2
+            qr/dependency/,
+            (qr/unnecessary/) x 3, qr/Dual dependency/, (qr/dependency/) x 2,
+            qr/unnecessary/,
         ) ] ],
         apply_fix => 1,
         file_contents_like => {
@@ -148,7 +145,7 @@ our @tests = (
     {
         # test for #682730 (reduces libclass-isa-perl | perl (<< 5.10.1-13) to perl)
         name => 'libclass-meta-perl',
-        check => { 'source Build-Depends-Indep:1' => 'libclass-isa-perl | perl (<< 5.11.0)' },
+        check => { 'source Build-Depends-Indep:1' => 'libclass-isa-perl' },
         apply_fix => 1,
     },
     {
@@ -264,6 +261,52 @@ our @tests = (
             'binary:bcftools Suggests:0' => "python"
         },
     },
+    {
+        name => 'rules-requires-root-non-ascii',
+        log4perl_load_warnings => [[
+            User => map {(warn => $_)} (qr/Current standards version/, qr/Invalid value/)
+        ]],
+        load => 'source Rules-Requires-Root="foo/bar"',
+        check => {
+            'source Rules-Requires-Root' => qr/no|binary-targets|([^\P{PosixGraph}\/]{2,}\/\p{PosixGraph}{2,}\s*)+/,
+        },
+    },
+    {
+        name => 'rules-requires-root-too-short',
+        log4perl_load_warnings => [[
+            User => map {(warn => $_)} (qr/Current standards version/,qr/Invalid value/)
+        ]],
+        load => 'source Rules-Requires-Root="no"',
+        check => {
+            'source Rules-Requires-Root' => qr/no|binary-targets|([^\P{PosixGraph}\/]{2,}\/\p{PosixGraph}{2,}\s*)+/,
+        },
+    },
+    {
+        name => 'rules-requires-root-invalid-item',
+        log4perl_load_warnings => [[
+            User => map {(warn => $_)} (qr/Current standards version/,qr/Invalid value/)
+        ]],
+        load => 'source Rules-Requires-Root="binary-targets"',
+        check => {
+            'source Rules-Requires-Root' => qr/no|binary-targets|([^\P{PosixGraph}\/]{2,}\/\p{PosixGraph}{2,}\s*)+/,
+        },
+    },
+    {
+        name => 'rules-requires-root-several-keywords',
+        log4perl_load_warnings => [[
+            User => map {(warn => $_)} (qr/Current standards version/,qr/Invalid value/)
+        ]],
+        load => 'source Rules-Requires-Root="abc/acme xyz/debian"',
+        check => {
+            'source Rules-Requires-Root' => qr/no|binary-targets|([^\P{PosixGraph}\/]{2,}\/\p{PosixGraph}{2,}\s*)+/,
+        },
+    },
+    {
+        name => 'init-system-helpers',
+        check => {
+            'source Build-Depends:1' => 'perl:any',
+        }
+    }
 );
 
 my $cache_file = 't/model_tests.d/dependency-cache.txt';
