@@ -7,15 +7,12 @@ $conf_dir       = 'debian/patches';
 
 $model_to_test  = "Dpkg::Patches";
 
-eval { require AptPkg::Config; };
-$skip = ( $@ or not -r '/etc/debian_version' ) ? 1 : 0;
-
 @tests = (
     { 
         name => 'debian-748502' ,
         # required to skip the bad patch (non dep-3)
         load_check => 'no',
-        load_warnings => [ qr/Ignoring patch/ ],
+        log4perl_load_warnings => [[ User => warn => qr/Ignoring patch/ ]],
         check => {
             'patches:tweak-defaults Synopsis' => 'Tweak defaults values for Debian'
         },
