@@ -7,6 +7,7 @@ use Carp::Assert::More;
 use strict;
 use warnings;
 use utf8;
+use Config::Model::Dpkg::Compat;
 
 our $conf_file_name = "";
 our $conf_dir       = '';
@@ -18,6 +19,8 @@ our $skip = ( $@ or not -r '/etc/debian_version' ) ? 1 : 0;
 our $home_for_test = '/home/joe' ;
 Config::Model::BackendMgr::_set_test_home($home_for_test) ;
 
+my $current_compat = Config::Model::Dpkg::Compat::_fetch_std;
+
 # required to set value that enable creation of dummy changelog:
 # changelog is computed from my_config email and name which are also
 # computed from environment variable. If any of these var is undef,
@@ -73,18 +76,18 @@ sub tweak {
     {   name => 't0',
         check => {
             'control source Build-Depends-Indep:3' => 'libtest-pod-perl',
+            # there's no apply_fix in this test, that's why compat and debhelper stay at 8
             'control source Build-Depends:0' => 'debhelper (>= 8)',
             'compat' => 8,
         },
         log4perl_load_warnings => [[
-            User => warn => qr/source Standards-Version/,
-            warn => qr/dual life/
+            User =>  map {(warn => $_)} qr/compat/, qr/source Standards-Version/, qr/Dual dependency/
         ]],
     },
 
     {   name => 't1',
         log4perl_load_warnings => [[
-            User => map {(warn => $_)} qr/standard/, qr/compat/, qr/canonical/, qr/invalid/
+            User => map {(warn => $_)} qr/compat/, qr/standard/, qr/compat/, qr/canonical/, qr/invalid/
         ]],
         apply_fix => 1 ,
         load => qq!patches:fix-spelling Description="more spelling details"!
@@ -98,8 +101,8 @@ sub tweak {
             'patches:glib-single-include Synopsis', "mega patchchoid",
             'patches:use-standard-dzil-test Description',
               "Test is modified in order not to load the Test:Dzil module\nprovided in t/lib",
-            'compat' => 8 , # test setup
-            'control source Build-Depends:0' => 'debhelper (>= 8~)' ,
+            'compat' => $current_compat , # test setup and fix
+            'control source Build-Depends:0' => "debhelper (>= $current_compat~)" ,
         },warnings => [ (qr/deprecated/) x 3 ],
     },
 
@@ -118,7 +121,7 @@ sub tweak {
         apply_fix => 1 ,
         check => {
             'control source Build-Depends-Indep:0' => 'perl',
-            'control source Build-Depends-Indep:1' => 'perl (>= 5.9.5) | libversion-perl (>= 0.7203)',
+            'control source Build-Depends-Indep:1' => 'libversion-perl',
             # check that duplicated dependency is removed
             'control source Build-Depends-Indep:2' => 'libdist-zilla-perl',
             'bugfiles:libversion bug-script' => qr/dummy script/,
